@@ -601,6 +601,7 @@ PMIX_EXPORT pmix_status_t PMIx_Init(pmix_proc_t *proc, pmix_info_t info[], size_
     pid_t pid;
     pmix_kval_t *kptr;
     pmix_iof_req_t *iofreq;
+    uint32_t u32;
 
     PMIX_ACQUIRE_THREAD(&pmix_global_lock);
 
@@ -610,8 +611,7 @@ PMIX_EXPORT pmix_status_t PMIx_Init(pmix_proc_t *proc, pmix_info_t info[], size_
          * rank should be known. So return them here if
          * requested */
         if (NULL != proc) {
-            pmix_strncpy(proc->nspace, pmix_globals.myid.nspace, PMIX_MAX_NSLEN);
-            proc->rank = pmix_globals.myid.rank;
+            PMIX_LOAD_PROCID(proc, pmix_globals.myid.nspace, pmix_globals.myid.rank);
         }
         ++pmix_globals.init_cntr;
         /* we also need to check the info keys to see if something need
@@ -736,7 +736,7 @@ PMIX_EXPORT pmix_status_t PMIx_Init(pmix_proc_t *proc, pmix_info_t info[], size_
         PMIX_CONSTRUCT(&pmix_server_globals.iof_residuals, pmix_list_t);
     } else {
         if (NULL != proc) {
-            pmix_strncpy(proc->nspace, evar, PMIX_MAX_NSLEN);
+            PMIX_LOAD_NSPACE(proc->nspace, evar);
         }
         PMIX_LOAD_NSPACE(pmix_globals.myid.nspace, evar);
         /* set the global pmix_namespace_t object for our peer */
@@ -763,10 +763,10 @@ PMIX_EXPORT pmix_status_t PMIx_Init(pmix_proc_t *proc, pmix_info_t info[], size_
         PMIX_RELEASE_THREAD(&pmix_global_lock);
         return PMIX_ERR_NOMEM;
     }
-    pmix_globals.mypeer->info->pname.nspace = strdup(proc->nspace);
-    pmix_globals.mypeer->info->pname.rank = proc->rank;
-    PMIX_LOAD_PROCID(pmix_globals.myidval.data.proc, proc->nspace, proc->rank);
-    pmix_globals.myrankval.data.rank = proc->rank;
+    pmix_globals.mypeer->info->pname.nspace = strdup(pmix_globals.myid.nspace);
+    pmix_globals.mypeer->info->pname.rank = pmix_globals.myid.rank;
+    PMIX_LOAD_PROCID(pmix_globals.myidval.data.proc, pmix_globals.myid.nspace, pmix_globals.myid.rank);
+    pmix_globals.myrankval.data.rank = pmix_globals.myid.rank;
 
     /* select our psec compat module - the selection will be based
      * on the corresponding envars that should have been passed
@@ -904,8 +904,7 @@ PMIX_EXPORT pmix_status_t PMIx_Init(pmix_proc_t *proc, pmix_info_t info[], size_
     PMIX_RELEASE_THREAD(&pmix_global_lock);
 
     /* look for a debugger attach key */
-    pmix_strncpy(wildcard.nspace, pmix_globals.myid.nspace, PMIX_MAX_NSLEN);
-    wildcard.rank = PMIX_RANK_WILDCARD;
+    PMIX_LOAD_PROCID(&wildcard, pmix_globals.myid.nspace, PMIX_RANK_WILDCARD);
     PMIX_INFO_LOAD(&ginfo, PMIX_OPTIONAL, NULL, PMIX_BOOL);
     if (PMIX_SUCCESS == PMIx_Get(&wildcard, PMIX_DEBUG_STOP_IN_INIT, &ginfo, 1, &val)) {
         pmix_output_verbose(2, pmix_client_globals.base_output,
@@ -913,37 +912,34 @@ PMIX_EXPORT pmix_status_t PMIx_Init(pmix_proc_t *proc, pmix_info_t info[], size_
                             pmix_globals.myid.nspace,
                             pmix_globals.myid.rank,
                             PMIX_RANK_PRINT(val->data.rank));
-        /* are we one of the procs to stop? */
-        if (PMIX_CHECK_RANK(val->data.rank, pmix_globals.myid.rank)) {
-            /* if the value was found, then we need to wait for debugger attach here */
-            /* register for the debugger release notification */
-            PMIX_CONSTRUCT_LOCK(&reglock);
-            PMIX_CONSTRUCT_LOCK(&releaselock);
-            PMIX_INFO_LOAD(&evinfo[0], PMIX_EVENT_RETURN_OBJECT, &releaselock, PMIX_POINTER);
-            PMIX_INFO_LOAD(&evinfo[1], PMIX_EVENT_HDLR_NAME, "WAIT-FOR-DEBUGGER", PMIX_STRING);
-            PMIX_INFO_LOAD(&evinfo[2], PMIX_EVENT_ONESHOT, NULL, PMIX_BOOL);
-            pmix_output_verbose(2, pmix_client_globals.event_output,
-                                "[%s:%d] REGISTERING WAIT FOR DEBUGGER", pmix_globals.myid.nspace,
-                                pmix_globals.myid.rank);
-            code = PMIX_DEBUGGER_RELEASE;
-            PMIx_Register_event_handler(&code, 1, evinfo, 3, notification_fn, evhandler_reg_callbk,
-                                        (void *) &reglock);
-            /* wait for registration to complete */
-            PMIX_WAIT_THREAD(&reglock);
-            PMIX_DESTRUCT_LOCK(&reglock);
-            PMIX_INFO_DESTRUCT(&evinfo[0]);
-            PMIX_INFO_DESTRUCT(&evinfo[1]);
-            /* notify the host that we are waiting */
-            PMIX_INFO_LOAD(&evinfo[0], PMIX_EVENT_NON_DEFAULT, NULL, PMIX_BOOL);
-            PMIX_INFO_LOAD(&evinfo[1], PMIX_BREAKPOINT, "pmix-init", PMIX_STRING);
-            PMIx_Notify_event(PMIX_READY_FOR_DEBUG, &pmix_globals.myid, PMIX_RANGE_RM,
-                              evinfo, 2, NULL, NULL);
-            PMIX_INFO_DESTRUCT(&evinfo[0]);
-            PMIX_INFO_DESTRUCT(&evinfo[1]);
-            /* wait for release to arrive */
-            PMIX_WAIT_THREAD(&releaselock);
-            PMIX_DESTRUCT_LOCK(&releaselock);
-        }
+        /* if the value was found, then we need to wait for debugger attach here */
+        /* register for the debugger release notification */
+        PMIX_CONSTRUCT_LOCK(&reglock);
+        PMIX_CONSTRUCT_LOCK(&releaselock);
+        PMIX_INFO_LOAD(&evinfo[0], PMIX_EVENT_RETURN_OBJECT, &releaselock, PMIX_POINTER);
+        PMIX_INFO_LOAD(&evinfo[1], PMIX_EVENT_HDLR_NAME, "WAIT-FOR-DEBUGGER", PMIX_STRING);
+        PMIX_INFO_LOAD(&evinfo[2], PMIX_EVENT_ONESHOT, NULL, PMIX_BOOL);
+        pmix_output_verbose(2, pmix_client_globals.event_output,
+                            "[%s:%d] REGISTERING WAIT FOR DEBUGGER", pmix_globals.myid.nspace,
+                            pmix_globals.myid.rank);
+        code = PMIX_DEBUGGER_RELEASE;
+        PMIx_Register_event_handler(&code, 1, evinfo, 3, notification_fn, evhandler_reg_callbk,
+                                    (void *) &reglock);
+        /* wait for registration to complete */
+        PMIX_WAIT_THREAD(&reglock);
+        PMIX_DESTRUCT_LOCK(&reglock);
+        PMIX_INFO_DESTRUCT(&evinfo[0]);
+        PMIX_INFO_DESTRUCT(&evinfo[1]);
+        /* notify the host that we are waiting */
+        PMIX_INFO_LOAD(&evinfo[0], PMIX_EVENT_NON_DEFAULT, NULL, PMIX_BOOL);
+        PMIX_INFO_LOAD(&evinfo[1], PMIX_BREAKPOINT, "pmix-init", PMIX_STRING);
+        PMIx_Notify_event(PMIX_READY_FOR_DEBUG, &pmix_globals.myid, PMIX_RANGE_RM,
+                          evinfo, 2, NULL, NULL);
+        PMIX_INFO_DESTRUCT(&evinfo[0]);
+        PMIX_INFO_DESTRUCT(&evinfo[1]);
+        /* wait for release to arrive */
+        PMIX_WAIT_THREAD(&releaselock);
+        PMIX_DESTRUCT_LOCK(&releaselock);
         PMIX_VALUE_FREE(val, 1); // cleanup memory
     } else {
         pmix_output_verbose(2, pmix_client_globals.base_output,
@@ -985,6 +981,32 @@ PMIX_EXPORT pmix_status_t PMIx_Init(pmix_proc_t *proc, pmix_info_t info[], size_
         PMIX_RELEASE(kptr); // maintain accounting
     }
 
+    /* get our app number */
+    rc = PMIx_Get(&pmix_globals.myid, PMIX_APPNUM, &ginfo, 1, &val);
+    if (PMIX_SUCCESS == rc) {
+        PMIX_VALUE_GET_NUMBER(rc, val, u32, uint32_t);
+        if (PMIX_SUCCESS == rc) {
+            pmix_globals.appnum = u32;
+        }
+        PMIX_VALUE_FREE(val, 1);
+    }
+    /* get our nodeid */
+    if (PMIX_SUCCESS == PMIx_Get(&pmix_globals.myid, PMIX_NODEID, &ginfo, 1, &val)) {
+        PMIX_VALUE_GET_NUMBER(rc, val, u32, uint32_t);
+        if (PMIX_SUCCESS == rc) {
+            pmix_globals.nodeid = u32;
+        }
+        PMIX_VALUE_FREE(val, 1);
+    }
+    /* get our hostname */
+    if (PMIX_SUCCESS == PMIx_Get(&pmix_globals.myid, PMIX_HOSTNAME, &ginfo, 1, &val)) {
+        if (PMIX_SUCCESS == rc) {
+            pmix_globals.hostname = val->data.string;
+            val->data.string = NULL;
+        }
+        PMIX_VALUE_FREE(val, 1);
+    }
+
     /* register the client supported attrs */
     rc = pmix_register_client_attrs();
     return rc;
